"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const CodeBuffer_1 = __importDefault(require("./CodeBuffer"));
const parsers = {
    json: JSON.parse,
    json5: function (source) {
        return require('json5').parse(source);
    },
    yaml: function (source) {
        return require('js-yaml').safeLoad(source);
    }
};
function compile(options) {
    let json;
    const { source, rootVar, format = 'json', filePath, getNamespace } = options;
    try {
        json = parsers[format](source);
    }
    catch (e) {
        console.error(`json parse error: ` + e.message);
        return {
            code: '',
            errors: [{
                    code: 1,
                    message: 'json parse error: ' + e.message
                }]
        };
    }
    const buffer = new CodeBuffer_1.default({
        root: rootVar,
        filePath
    });
    if ('$title' in json) {
        delete json.$title;
    }
    if ('$preprocesser' in json) {
        const preprocesser = json.$preprocesser;
        buffer.addPreprocesser(preprocesser, getNamespace);
        delete json.$preprocesser;
    }
    buffer.walk(json);
    const code = buffer.toString();
    return {
        code,
        errors: []
    };
}
exports.default = compile;
//# sourceMappingURL=compiler.js.map